WeeWX Copyright {#weewx-copyright} - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# WeeWX Copyright

Copyright 2009-2023 by Thomas Keffer (tkeffer@gmail.com), Matthew Wall, and Gary Roderick.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

http://www.gnu.org/licenses

The WMR9x8 driver is Copyright Will Page.

The FineOffsetUSB driver is Copyright Matthew Wall, based on the open source pywws by Jim Easterbrook.

The WS23xx driver is Copyright Matthew Wall, including significant portions from ws2300 by Russel Stuart.

The WS28xx driver is Copyright Matthew Wall, based on the original Python implementation by Eddi de Pieri and with significant contributions by LJM Heijst.

The TE923 driver is Copyright Matthew Wall with significant contributions from Andrew Miles.

The CC3000 driver is Copyright Matthew Wall, thanks to hardware contributed by Annie Brox.

The WS1 driver is Copyright Matthew Wall.

The Ultimeter driver is Copyright Matthew Wall and Nate Bargmann.

The Acurite driver is Copyright Matthew Wall.

The WMR300 driver is Copyright Matthew Wall, thanks to hardware contributed by EricG.

Some icons are Copyright Tatice (http://tatice.deviantart.com), licensed under the terms of Creative Commons Attribution-NonCommercial-NoDerivs 3.0.

The debian, redhat, and suse packaging configurations are Copyright Matthew Wall, licensed under the terms of GNU Public License 3.